Receiver

Struct Receiver 

pub struct Receiver<T> { /* private fields */ }
Receive part of Sender.

Implementations

Source

impl<T> Receiver<T>

pub fn borrow(&self) -> Ref<'_, T>

Borrows the latest value but does not mark it as seen.

pub fn borrow_and_update(&mut self) -> Ref<'_, T>

Borrows the latest value and marks it as seen.

pub async fn changed(&mut self) -> Result<Ref<'_, T>, RecvError>

Blocks and consumes new change since last Receiver::borrow_and_update or Receiver::changed().

If multiple values are published in the meantime, it is likely that only later one got observed. It is guaranteed that the final value after all Senders dropped is always observed.

Errors