pub struct Receiver<T> { /* private fields */ }Expand description
Receive part of Sender.
Implementations
Sourceimpl<T> Receiver<T>
impl<T> Receiver<T>
Sourcepub fn borrow_and_update(&mut self) -> Ref<'_, T>
pub fn borrow_and_update(&mut self) -> Ref<'_, T>
Borrows the latest value and marks it as seen.
Sourcepub async fn changed(&mut self) -> Result<Ref<'_, T>, RecvError>
pub async fn changed(&mut self) -> Result<Ref<'_, T>, RecvError>
Blocks and consumes new change since last Receiver::borrow_and_update or Receiver::changed().
If multiple values are published in the meantime, it is likely that only later one got observed. It is guaranteed that the final value after all Senders dropped is always observed.
Errors